/* SPDX-License-Identifier: LGPL-2.1-or-later */
/*
 * Copyright (C) 2020, Google Inc.
 *
 * starfive_ipa_interface.h - Image Processing Algorithm interface for starfive
 *
 * This file is auto-generated. Do not edit.
 */

#pragma once

#include <libcamera/ipa/core_ipa_interface.h>
#include <libcamera/ipa/ipa_interface.h>


#include <vector>

namespace libcamera {

namespace ipa {

namespace starfive {




enum class _StarfiveCmd {
	Exit = 0,
	Init = 1,
	Start = 2,
	Stop = 3,
	Configure = 4,
	IsSensorISPEnabled = 5,
	MapBuffers = 6,
	UnmapBuffers = 7,
	QueueRequest = 8,
	StatBufferReady = 9,
};

enum class _StarfiveEventCmd {
	SetDelayedControls = 1,
	SetIspControls = 2,
	CompleteGetInfo = 3,
};


struct ssParams
{
public:
#ifndef __DOXYGEN__
	ssParams()
		: outWidth(0), outHeight(0)
	{
	}

	ssParams(uint16_t _outWidth, uint16_t _outHeight)
		: outWidth(_outWidth), outHeight(_outHeight)
	{
	}
#endif


	uint16_t outWidth;
	uint16_t outHeight;
};

class IPAStarfiveInterface : public IPAInterface
{
public:

	virtual int32_t init(
		const IPASettings &settings,
		const IPACameraSensorInfo &sensorInfo,
		const ControlInfoMap &sensorControls) = 0;

	virtual int32_t start(
		const ControlList &controls) = 0;

	virtual void stop() = 0;

	virtual int32_t configure(
		const ControlInfoMap &ispControls,
		const ControlInfoMap &sensorControls,
		const IPACameraSensorInfo &sensorInfo,
		const std::vector<ipa::starfive::ssParams> &outSSParams) = 0;

	virtual bool isSensorISPEnabled() = 0;

	virtual void mapBuffers(
		const std::vector<libcamera::IPABuffer> &buffers) = 0;

	virtual void unmapBuffers(
		const std::vector<uint32_t> &ids) = 0;

	virtual void queueRequest(
		const ControlList &controls) = 0;

	virtual void statBufferReady(
		const uint32_t bufferId,
		const ControlList &sensorControls) = 0;

	Signal<const ControlList &> setDelayedControls;

	Signal<const ControlList &> setIspControls;

	Signal<uint32_t, bool> completeGetInfo;
};

} /* namespace starfive */

} /* namespace ipa */

} /* namespace libcamera */